@@ -14,13 +14,18 @@ class FakeContainer:
     }
     attrs = {
         "HostConfig": {
-            "PortBindings": {"80/tcp": [{"HostIp": "", "HostPort": "1976"}]},
+            "PortBindings": {"1976/tcp": [{"HostIp": "", "HostPort": "1976"}]},
         }
     }
 
+    status = "running"
+
+    def remove(*args, **kwargs):
+        ...
+
 
 class FakeContainerModule:
-    def list(*args):
+    def list(*args, **kwargs):
         return [FakeContainer]
 
     def run(*args, **kwargs):
@@ -32,10 +37,24 @@ class FakeImageModule:
         pass
 
 
+class FakeVolume:
+    def remove(*args, **kwargs):
+        ...
+
+
+class FakeVolumesModule:
+    def get(*args, **kwargs):
+        return FakeVolume()
+
+    def create(*args, **kwargs):
+        ...
+
+
 class FakeDockerClient:
     def __init__(self, *args, **kwargs) -> None:
         self.containers = FakeContainerModule
         self.images = FakeImageModule
+        self.volumes = FakeVolumesModule
 
 
 @pytest.fixture(autouse=True)
@@ -51,7 +70,13 @@ def test_runner(monkeypatch):
     return CliRunner()
 
 
-def test_command_list(tmp_path: Path, test_runner: CliRunner):
+def test_command_init(tmp_path: Path, test_runner: CliRunner):
     result = test_runner.invoke(app, ["init", str(tmp_path)])
     assert result.exit_code == 0
     assert "Completed initializing project directory:" in result.stdout
+
+
+def test_command_version(test_runner: CliRunner):
+    result = test_runner.invoke(app, ["--version"])
+    assert result.exit_code == 0
+    assert "Starpack CLI version" in result.stdout
